import squint.*;
import javax.swing.*;
import java.awt.Font;

/**
 * POPClient --- This program allows its user to view
 * mail messages accessed through a POP server.
 */
public class POPClient extends GUIManager {

    // Change these values to adjust the size of the program's window
    private final int WINDOW_WIDTH = 650, WINDOW_HEIGHT = 470;
   
    // The server to use
    private final String SERVER = "cortland.cs.williams.edu";
    
    // The standard POP port
    private final int POP_PORT = 110;
    
    // User interface buttons
    private JButton login = new JButton( "Connect" );
    private JButton logout = new JButton( "Disconnect" );
    private JButton request = new JButton( "Get message" );

    // Used to enter the POP account identifier
    private JTextField user = new JTextField( 20 );

    // Used to enter the POP account password
    private JPasswordField pass = new JPasswordField( 15 );
        
    // Email messages are displayed in this area
    private JTextArea message = new JTextArea( 20, 50 );
        
    // +OK and -ERR messages from the server are displayed in this area
    private JTextArea log = new JTextArea( 5, 50 );
    
    // Our connection to the POP server
    private POPConnection toServer;
    
    // Menu used to select messages;
    private JComboBox messageSelector;
    
    private boolean connected = false;
            
   /*
    * Install all of the required GUI components
    */
    public POPClient() {
        this.createWindow( WINDOW_WIDTH, WINDOW_HEIGHT );
        
        // Each JLabel/JTextArea pair is placed together in a panel of their own
        JPanel curPanel;
        
        // Initial button states
        login.setEnabled( true );
        logout.setEnabled( false );
        request.setEnabled( false );

        // Create fields for entering the account information
        curPanel = new JPanel();
        curPanel.add( new JLabel( "Mail Account:" ) );
        curPanel.add( user );
        contentPane.add( curPanel );
        
        curPanel = new JPanel();
        curPanel.add( new JLabel( "Password:" ) );
        curPanel.add( pass );
        contentPane.add( curPanel );
                
                // Create a field for the message number
        curPanel = new JPanel();
        curPanel.add( login );
        curPanel.add( logout );
        contentPane.add( curPanel );

        // Install the retrieve button and text areas in the window
        contentPane.add( new JScrollPane( message ) );
        //contentPane.add( new JScrollPane( log ) );
    }
   
   /*
    * When the button is clicked, interact with the POP server to
    * access the requested message.
    */
    public void buttonClicked( JButton which ) {
        String serverResponse;
        
        if ( which == login ) {
            // Connect to the server and display initial response
            toServer = new POPConnection();
            if (toServer.login(SERVER, user.getText(), new String(pass.getPassword()))) {
                int totalMessages = toServer.messagesAvailable();
                
                messageSelector = new JComboBox();
                messageSelector.setFont( new Font( "Courier", Font.PLAIN, 12 ) );
                int messNum = 1;
                while ( messNum <= totalMessages ) {
                    messageSelector.addItem( toServer.getMessage( messNum ).shortSummary() );
                    messNum = messNum + 1;
                }
                contentPane.add( messageSelector );
                connected = true;
            } else {
                message.setText( "Unable to login.  Check you password." );
            }
            
        } else if ( which == logout ) {
            // Terminate the connection
            toServer.close();
            contentPane.remove( messageSelector );
            connected = false;
        }
        
        login.setEnabled( ! connected );
        logout.setEnabled( connected );
        request.setEnabled( connected );
        repaint();
    }
   
    /**
     *  Request the selected message from the server
     *  and display it in the text area.
     **/
    public void menuItemSelected() {
        MailMessage requested = toServer.getMessage( messageSelector.getSelectedIndex() + 1 );
        if ( requested == null ) {
            message.setText( "Unable to retrieve message" );
        } else {
            message.setText( requested.toString() );
            message.setCaretPosition(0);
        }
     }
     
     /**
      * Simulate clicking the login button
      */
     public void textEntered() {
         login.doClick();
        }
                   
}
