import squint.*;

/**
 * Provides some standard POP server functions like
 * 1.  Logging in to the pop server
 * 2.  Grabbing Messages
 * 3.  Checking how many messages are available
 * 4.  Logging out of the pop server
 */
public class POPConnection {

    private final int POP_PORT = 110;

    /**
     * The connection to the POP server
     */
    private NetConnection toServer;
        
    public POPConnection( ) {
        
    }
    
    /**
     * Login to 'server' with 'id' and 'password'.  Return true if and only if 
     * the login is successful.
     */
    public boolean login(String server, String id, String password) {
        toServer = new NetConnection( server, POP_PORT );
        toServer.in.nextLine();
        toServer.out.println( "USER " + id );
        toServer.in.nextLine();
        toServer.out.println( "PASS " + password );
        if ( ! toServer.in.nextLine().startsWith( "+OK" ) ) {
            close();
            return false;
        } else {
            return true;
        }
    }
    
    /**
     * Grab the 'messageNum' mail message from the server.
     * Return null if the message does not exist.
     */
    public MailMessage getMessage( int messageNum ) {
        toServer.out.println( "RETR " + messageNum );
        if ( toServer.in.nextLine().startsWith( "+OK" ) ) {
            String response = toServer.in.nextLine();
            MailMessage result = new MailMessage();
            while ( ! response.equals( "." ) ) {
                result.append( response );
                response = toServer.in.nextLine();
            }
            return result;
        } else {
            return null;
        }
    }
    
    /**
     * Return the number of available message from the server.
     */
    public int messagesAvailable() {
        toServer.out.println( "STAT" );
        String response = toServer.in.nextLine();
        if ( response.startsWith( "+OK" ) ) {
            String num = response.substring( "+OK ".length() );
            num = num.substring( 0, num.indexOf( " " ) );
            return Integer.parseInt( num );
        }
        return -1;
    }
    
    /**
     * log out of the POP Server
     */
    public void close() {
        toServer.out.println( "QUIT" );
        toServer.in.nextLine();
        toServer.close();
    }
        
}